@@ -1,13 +1,11 @@
 #ifndef OIDC_AGENT_API_H
 #define OIDC_AGENT_API_H
 
+#include "accounts.h"
 #include "error.h"
 #include "memory.h"
 #include "mytokens.h"
 #include "response.h"
 #include "tokens.h"
-#if defined __MINGW32__ || defined __MINGW64__ || defined _WIN32
-#include "accounts.h"
-#endif
 
 #endif  // OIDC_AGENT_API_H
