@@ -4,7 +4,10 @@
 
 #include "utils/string/stringUtils.h"
 
-char* removeScope(char* scopes, char* rem) {
+char* removeScope(char* scopes, const char* rem) {
+  if (scopes == NULL || rem == NULL) {
+    return scopes;
+  }
   scopes = strremove(scopes, rem);
   scopes = strelimIfAfter(
       scopes, ' ',
