@@ -1,6 +1,6 @@
 #ifndef OIDC_AGENT_OIDCUTILS_H
 #define OIDC_AGENT_OIDCUTILS_H
 
-char* removeScope(char* scopes, char* rem);
+char* removeScope(char* scopes, const char* rem);
 
 #endif  // OIDC_AGENT_OIDCUTILS_H
