@@ -1,4 +1,4 @@
-#define _XOPEN_SOURCE 500
+#define _GNU_SOURCE
 #include "system_runner.h"
 
 #include <errno.h>
@@ -7,6 +7,11 @@
 #include <sys/types.h>
 #include <unistd.h>
 
+#include "defines/msys.h"
+#ifndef ANY_MSYS
+#include <signal.h>
+#endif
+
 #include "utils/file_io/file_io.h"
 #include "utils/logger.h"
 #include "utils/memory.h"
@@ -124,6 +129,15 @@ char* getOutputFromCommand(const char* cmd) {
     return NULL;
   }
 
+#ifndef __APPLE__
+  static sighandler_t old;
+#else
+  static sig_t old;
+#endif
+#ifndef ANY_MSYS
+  old = signal(SIGCHLD, SIG_DFL);
+#endif
+
   logger(DEBUG, "Running command: %s", cmd);
   /* Open the command for reading. */
 #if defined __MSYS__ || defined _WIN32
@@ -138,7 +152,17 @@ char* getOutputFromCommand(const char* cmd) {
     return NULL;
   }
   char* ret = readFILE(fp);
-  pclose(fp);
+  int   st  = pclose(fp);
+#ifndef ANY_MSYS
+  signal(SIGCHLD, old);
+#endif
+  if (WIFEXITED(st)) {
+    int status = WEXITSTATUS(st);
+    if (status != 0) {
+      secFree(ret);
+      return NULL;
+    }
+  }
   return ret;
 }
 
